# Cubespec PUNA

This project provides all the functionality to control the Symétrie PUNA Hexapod
in order to position the secondary mirror for the CubeSpec CubeSat.

# Initialise the Project

Create a folder and install the package:

```
$ mkdir -p ~/cubespec_puna
$ cd ~/cubespec_puna
$ uv install cubespec_puna
# cgse init
```
